Welcome to the piecash documentation! — Python interface to GnuCash documents 0.14.1 documentation

# Welcome to the piecash documentation!

Release: | 0.14.1
Date: | Feb 07, 2018
Authors: | sdementen
Project page: | https://github.com/sdementen/piecash

- What’s new

Contents:

- Documentation
  - Installation
  - Quickstart
  - The piecash command line interface
- Tutorial : using existing objects
  - Opening an existing Book
  - Access to objects
  - Accounts
  - Commodities and Prices
  - Transactions and Splits
  - Invoices
  - Other objects
  - Working with slots
- Tutorial : creating new objects
  - Creating a new Book
  - Creating a new Account
  - Creating a new Commodity
  - Creating a new Transaction
  - Creating new Business objects
- Examples of programs written with piecash
  - Creating and opening gnucash files
  - Creating an account
  - Creating a transaction
  - Simple changes on a newly created book
  - Create a book with some accounts and add a transaction
  - Extract Split information as pandas DataFrame
  - Filtered transaction reports
- piecash and the official python bindings

# For developers

The complete api documentation (apidoc) :

- piecash package

An overall view on the core objects in GnuCash:

- GnuCash SQL Object model and schema

A list of resources used for the project:

- Resources

The todo list:

- write more tests
- review non core objects (`budget`, `business`)
- build a single exe to ease install on windows (following http://milkator.wordpress.com/2014/07/19/windows-executable-from-python-developing-in-ubuntu/)

# Indices and tables

> - Index
> - Module Index
> - Search Page